==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/Input/flac/translations/flac_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="60"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="62"/>
        <source>FLAC Files</source>
        <translation>Файлы FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="200"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Об аудио-модуле FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="201"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудио-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="202"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation>Кб/с</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>

==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Input/flac/translations/flac_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="61"/>
        <source>FLAC Plugin</source>
        <translation>Модуль FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="63"/>
        <source>FLAC Files</source>
        <translation>Файлы FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="204"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Об аудио-модуле FLAC</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="205"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Аудио-модуль FLAC для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="206"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="92"/>
        <source>Length</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Sample rate</source>
        <translation>Дискретизация</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="93"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="94"/>
        <source>Channels</source>
        <translation>Каналов</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>Bitrate</source>
        <translation>Битовая частота</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="95"/>
        <source>kbps</source>
        <translation>кбит/с</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="96"/>
        <source>KB</source>
        <translation>КБ</translation>
    </message>
</context>
</TS>
